==> tine20-felamimail_2018.08.9.tar.bz2: Felamimail/js/Felamimail-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Type"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Delete"
: "Изтрий"

, "Reply"
: "Отговори"

, "Reply To All"
: "Отговори на всички"

, "Forward"
: "Препрати"

, "Save"
: ""

, "Print Message"
: ""

, "Print Preview"
: ""

, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "Empty Folder"
: "Изпразни папка"

, "Add Folder"
: "Добави папка"

, "New {0}"
: "Нова {0}"

, "Folder, Folders"
: [
  ""
 ,""

]
, "Please enter the name of the new {0}:"
: "Моля задайте име на новата {0}:"

, "No {0} added"
: "Няма добавена {0}"

, "You have to supply a {0} name!"
: "Трябва да зададете име на {0}!"

, "Please wait"
: "Моя изчакайте"

, "Creating {0}..."
: "Създава {0}..."

, "Edit Account"
: "Редактирай конто"

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Notifications"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "No Messages found."
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: ""

, "Move"
: ""

, "File Message"
: ""

, "Add Account"
: "Добави конто"

, "Id"
: "Id"

, "Attachments"
: "Прикачени документи"

, "Flags"
: ""

, "Subject"
: "Subject"

, "From (Email)"
: ""

, "From (Name)"
: ""

, "Sender"
: ""

, "To"
: "До"

, "Sent"
: "Изпрати"

, "Received"
: "Получени"

, "Size"
: "Големина"

, "Answered"
: "Отговорени"

, "Forwarded"
: "Препратени"

, "Tine20"
: ""

, "Recent"
: "Нови"

, "Select Save Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Compose email"
: ""

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "None"
: "Нищо"

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "Loading Mail Addresses"
: ""

, "Message, Messages"
: [
  "Съобщение"
 ,"Съобщение"

]
, "Subject/From"
: ""

, "Cc"
: "Копие"

, "Bcc"
: "Сляпо копие"

, "Account, Accounts"
: [
  "Конто"
 ,"Конто"

]
, "Email Accounts, Email Accounts"
: [
  ""
 ,""

]
, "INBOX"
: ""

, "Drafts"
: ""

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "record list, record lists"
: [
  "Листа на съобщенията"
 ,"Листи на съобщенията"

]
, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "New Mail"
: ""

, "Email"
: "Емайл"

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: ""

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: "IMAP входни данни за {0}"

, "Credentials"
: "Входни данни"

, "IMAP Error"
: ""

, "No connection to IMAP server."
: ""

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: "To:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: ""

, "Send"
: "Изпрати"

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Save Email Note"
: ""

, "Activate this toggle button to save the email text as a note attached to the recipient(s) contact(s)."
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: "Неуспешно"

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: "Оригинално съобщение"

, "Compose email:"
: "Напиши емайл:"

, "From"
: "От"

, "Convert to formated text"
: ""

, "Body"
: "Съобщение"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Reply-To Email"
: ""

, "Add email address here for reply-to"
: ""

, "Warning"
: ""

, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Keep a copy"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Keep mail"
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "Notification for {0}"
: ""

, "Notification Email"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "Vacation Message for {0}"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Add New Account"
: ""

, "Signature"
: "Подпис"

, "Account Name"
: "Име на конто"

, "User Email"
: "Емайл адрес"

, "User Name (From)"
: "Емайл на подател"

, "Organization"
: "Фирма"

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: "IMAP"

, "Host"
: "Host"

, "Port (Default: 143 / SSL: 993)"
: ""

, "Secure Connection"
: "Сигурна връзка"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Потребителско име"

, "Password"
: "Парола"

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: ""

, "Authentication"
: "Разпознаване"

, "Login"
: "Login"

, "Plain"
: "Текст"

, "Username (optional)"
: "Ротребителско име (по избор)"

, "Password (optional)"
: "Парола (по избор)"

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Other Settings"
: "Други настройки"

, "Sent Folder Name"
: "Име на папка Изпратени"

, "Trash Folder Name"
: "Име на папка Изтрити"

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: ""

, "HTML"
: ""

, "Plain Text"
: ""

, "Depending on content type (experimental)"
: ""

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Open in Felamimail"
: ""

, "Message not available."
: ""

, "Add"
: "Добави"

, "Add contact to addressbook"
: "Добави контакт в списъка с адреси"

, "Date"
: ""

, "Show or hide header information"
: "Показва или скрива header"

, "Download"
: ""

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Failure"
: ""

, "This file is already attached to this record."
: ""

, "All inboxes"
: ""

, "Default Email Account"
: "Адрес по настройки"

, "The default email account to use when sending mails."
: "Използван адрес по настройки при изпращане на емайли."

, "Email Update Interval"
: ""

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: ""

, "Save Note default Value."
: ""

, "Confirm Delete"
: ""

, "Show confirmation dialog when deleting mails."
: ""

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "manage email accounts"
: ""

, "Edit and delete email accounts"
: ""

, "Add email accounts"
: ""

, "Create new email accounts"
: ""

, "Out of Office reply from %1$s"
: ""

, "You have new mail from "
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "Message File Location"
: ""

, "{0} unread message"
: ""

, "Folder"
: ""

, "Message"
: "Съобщение"

, "Account"
: "Конто"

, "Email Accounts"
: ""

, "record list"
: "Листа на съобщенията"

, "Vacation"
: ""

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-felamimail_2019.08.4.tar.bz2: Felamimail/js/Felamimail-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All inboxes"
: ""

, "Default Email Account"
: "Адрес по настройки"

, "The default email account to use when sending mails."
: "Използван адрес по настройки при изпращане на емайли."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: ""

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: ""

, "Save Note default Value."
: ""

, "Confirm Delete"
: ""

, "Show confirmation dialog when deleting mails."
: ""

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Message not available."
: ""

, "File Message"
: ""

, "Filemanager ..."
: ""

, "Attachment"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "File Messages as Attachment"
: ""

, "Add New Account"
: ""

, "Permissions"
: ""

, "Account, Accounts"
: [
  "Конто"
 ,"Конто"

]
, "Account Name"
: "Име на конто"

, "Account Type"
: ""

, "User"
: ""

, "User Email"
: "Емайл адрес"

, "User Name (From)"
: "Емайл на подател"

, "Organization"
: "Фирма"

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: "IMAP"

, "Host"
: "Host"

, "Port (Default: 143 / SSL: 993)"
: ""

, "Secure Connection"
: "Сигурна връзка"

, "None"
: "Нищо"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Потребителско име"

, "Password"
: "Парола"

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: ""

, "Authentication"
: "Разпознаване"

, "Login"
: "Login"

, "Plain"
: "Текст"

, "Username (optional)"
: "Ротребителско име (по избор)"

, "Password (optional)"
: "Парола (по избор)"

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Notification Email"
: ""

, "Other Settings"
: "Други настройки"

, "Sent Folder Name"
: "Име на папка Изпратени"

, "Trash Folder Name"
: "Име на папка Изтрити"

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: ""

, "HTML"
: ""

, "Plain Text"
: ""

, "Depending on content type (experimental)"
: ""

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Additional Personal External Account"
: ""

, "Default Personal System Account"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: "To:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: ""

, "Compose email"
: ""

, "To"
: "До"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Empty Folder"
: "Изпразни папка"

, "Add Folder"
: "Добави папка"

, "New {0}"
: "Нова {0}"

, "Folder, Folders"
: [
  ""
 ,""

]
, "Please enter the name of the new {0}:"
: "Моля задайте име на новата {0}:"

, "No {0} added"
: "Няма добавена {0}"

, "You have to supply a {0} name!"
: "Трябва да зададете име на {0}!"

, "Please wait"
: "Моя изчакайте"

, "Creating {0}..."
: "Създава {0}..."

, "Edit Account"
: "Редактирай конто"

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Notifications"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "Loading Mail Addresses"
: ""

, "Open in Felamimail"
: ""

, "Subject"
: "Subject"

, "From"
: "От"

, "Add"
: "Добави"

, "Add contact to addressbook"
: "Добави контакт в списъка с адреси"

, "Date"
: ""

, "Show or hide header information"
: "Показва или скрива header"

, "Attachments"
: "Прикачени документи"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "Delete"
: "Изтрий"

, "Reply"
: "Отговори"

, "Reply To All"
: "Отговори на всички"

, "Forward"
: "Препрати"

, "Print Message"
: ""

, "Print Preview"
: ""

, "Notification for {0}"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Keep a copy"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "Vacation Message for {0}"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "From (Email)"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Size"
: "Големина"

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Failure"
: ""

, "This file is already attached to this record."
: ""

, "Send"
: "Изпрати"

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: "Неуспешно"

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: "Оригинално съобщение"

, "Compose email:"
: "Напиши емайл:"

, "Convert to formated text"
: ""

, "Body"
: "Съобщение"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  "Подпис"
 ,"Подпис"

]
, "Warning"
: ""

, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "Message, Messages"
: [
  "Съобщение"
 ,"Съобщение"

]
, "Subject/From"
: ""

, "From (Name)"
: ""

, "Cc"
: "Копие"

, "Bcc"
: "Сляпо копие"

, "Flags"
: ""

, "Received"
: "Получени"

, "INBOX"
: ""

, "Drafts"
: ""

, "Sent"
: "Изпрати"

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "record list, record lists"
: [
  "Листа на съобщенията"
 ,"Листи на съобщенията"

]
, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "No Messages found."
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: ""

, "Move"
: ""

, "Add Account"
: "Добави конто"

, "Id"
: "Id"

, "Sender"
: ""

, "Answered"
: "Отговорени"

, "Forwarded"
: "Препратени"

, "Tine20"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "New Mail"
: ""

, "Email"
: "Емайл"

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: ""

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: "IMAP входни данни за {0}"

, "Credentials"
: "Входни данни"

, "IMAP Error"
: ""

, "No connection to IMAP server."
: ""

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Out of Office reply from %1$s"
: ""

, "You have new mail from "
: ""

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Type"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Is default"
: ""

, "manage email accounts"
: ""

, "Edit and delete email accounts"
: ""

, "Add email accounts"
: ""

, "Create new email accounts"
: ""


, "Account"
: "Конто"

, "Folder"
: ""

, "{0} unread message"
: ""

, "Signature"
: "Подпис"

, "Message"
: "Съобщение"

, "record list"
: "Листа на съобщенията"

, "Vacation"
: ""

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

, "Message File Suggestion"
: ""

, "Message File Location"
: ""

, "Email Account"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
